import React from 'react';
import { FileRejection } from 'react-dropzone';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type FileUploaderProps = PropsWithMetadata<{
    /** Allows providing a list of supported file extensions */
    accept?: string;
    /** Allows user to select multiple files or restrict it to only single file */
    multiple?: boolean;
    /** Allows providing a custom class name */
    className?: string;
    /** Allows providing the description message which is shown on the uploader */
    description: string;
    /** Allows disabling the uploader */
    disabled?: boolean;
    /** Allows providing an image for the uploader, this value will be passed to src attribute of the image tag */
    image?: string;
    /** Allows providing the maximum file size supported by the uploader */
    maxFileSize?: number;
    /** Allows providing a callback for when dragenter event occurs */
    onDragEnter?: () => void;
    /** Allows providing a callback for when dragleave event occurs */
    onDragLeave?: () => void;
    /** Allows providing a callback for when dragover event occurs */
    onDragOver?: () => void;
    /** Allows providing a text to be shown when dragging over the uploader */
    onDragOverText: string;
    /** Allows providing a callback for when drop event occurs */
    onDrop: (acceptedFiles: File[], rejectedFiles: FileRejection[]) => void;
    /** Allows showing or hiding the image */
    showIcon?: boolean;
    /** Allows providing a title to be shown for the uploader */
    title?: string;
}>;
export declare const FileUploader: React.ForwardRefExoticComponent<{
    /** Allows providing a list of supported file extensions */
    accept?: string | undefined;
    /** Allows user to select multiple files or restrict it to only single file */
    multiple?: boolean | undefined;
    /** Allows providing a custom class name */
    className?: string | undefined;
    /** Allows providing the description message which is shown on the uploader */
    description: string;
    /** Allows disabling the uploader */
    disabled?: boolean | undefined;
    /** Allows providing an image for the uploader, this value will be passed to src attribute of the image tag */
    image?: string | undefined;
    /** Allows providing the maximum file size supported by the uploader */
    maxFileSize?: number | undefined;
    /** Allows providing a callback for when dragenter event occurs */
    onDragEnter?: (() => void) | undefined;
    /** Allows providing a callback for when dragleave event occurs */
    onDragLeave?: (() => void) | undefined;
    /** Allows providing a callback for when dragover event occurs */
    onDragOver?: (() => void) | undefined;
    /** Allows providing a text to be shown when dragging over the uploader */
    onDragOverText: string;
    /** Allows providing a callback for when drop event occurs */
    onDrop: (acceptedFiles: File[], rejectedFiles: FileRejection[]) => void;
    /** Allows showing or hiding the image */
    showIcon?: boolean | undefined;
    /** Allows providing a title to be shown for the uploader */
    title?: string | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined; /** Allows disabling the uploader */
} & React.RefAttributes<HTMLDivElement>>;
